@@ -537,7 +537,7 @@ class ucs:
 
     def init_debug(self):
         udm_debug_level = self.configRegistry.get_int(f'{self.CONFIGBASENAME}/debug/udm/level', ud.WARN)
-        structured = self.configRegistry.is_true(f'{self.CONFIGBASENAME}/debug/structured-logging', False)
+        structured = self.configRegistry.is_true(f'{self.CONFIGBASENAME}/debug/structured-logging', True)
         univention.logging.basicConfig(filename=self._logfile, univention_debug_level=self._debug_level, use_structured_logging=structured)
         logging.getLogger('ADMIN').set_ud_level(udm_debug_level)
 
