@@ -157,12 +157,14 @@ def get_sid_mapping():
 def _map_s4_to_udm_base64(property_name):
     def mapping(connector, key, obj):
         return [base64.b64encode(x) for x in obj['attributes'][property_name]]
+
     return mapping
 
 
 def _map_ldap_to_s4(property_name):
     def mapping(connector, key, obj):
         return obj['attributes'][property_name]
+
     return mapping
 
 
@@ -230,7 +232,7 @@ s4_mapping = {
         post_con_modify_functions=list(filter(None, [
             univention.s4connector.s4.sid_mapping.sid_to_s4 if configRegistry.is_true('connector/s4/mapping/sid_to_s4', False) and not configRegistry.is_true('connector/s4/mapping/sid', True) else None,
             univention.s4connector.s4.password.password_sync_ucs_to_s4,
-            univention.s4connector.s4.password.lockout_sync_ucs_to_s4,
+            univention.s4connector.s4.password.lockout_sync_from_ucs,
             univention.s4connector.s4.primary_group_sync_from_ucs,
             univention.s4connector.s4.object_memberships_sync_from_ucs,
             univention.s4connector.s4.disable_user_from_ucs,
@@ -238,7 +240,7 @@ s4_mapping = {
         post_ucs_modify_functions=list(filter(None, [
             univention.s4connector.s4.sid_mapping.sid_to_ucs if configRegistry.is_true('connector/s4/mapping/sid_to_ucs', True) and not configRegistry.is_true('connector/s4/mapping/sid', True) else None,
             univention.s4connector.s4.password.password_sync_s4_to_ucs,
-            univention.s4connector.s4.password.lockout_sync_s4_to_ucs,
+            univention.s4connector.s4.password.lockout_sync_to_ucs,
             univention.s4connector.s4.primary_group_sync_to_ucs,
             univention.s4connector.s4.object_memberships_sync_to_ucs if configRegistry.get('connector/s4/mapping/group/syncmode') != 'write' else None,
             univention.s4connector.s4.disable_user_to_ucs,
@@ -1510,7 +1512,6 @@ s4_mapping = {
                 con_attribute='appSchemaVersion',
                 single_value=True,
             ),
-
         },
     ),
     'ms/gpsi-package-registration': univention.s4connector.property(
@@ -1925,7 +1926,7 @@ s4_mapping = {
         con_sync_function=univention.s4connector.s4.dc.ucs2con,
         ucs_sync_function=univention.s4connector.s4.dc.con2ucs,
     ),
-}
+}  # fmt: skip
 
 if not configRegistry.is_true('connector/s4/mapping/gpo', True):
     s4_mapping['container'].attributes.pop('gPLink')
